pub struct ProcessSet<K> { /* private fields */ }

Implementations

Wait for any process to finish, and return the corrosponding key and resulting child (or error).

Takes in a signal handler from outside which can be created with SignalHandler::default(). This ensures that signals between waits are not missed.

If multiple processes have finished, this will only return one of them. Call this function in a loop to wait for all processes to finish.

If no process has finished, this will pause the current thread.

If there are no processes running, this will return NoProcessesRunning.

If, during the middle of waiting, the current process gets a SIGINT or SIGTERM, this will return ReceivedTerminationSignal(signal_number). More signals can be added via SignalHandler::add_termination_signal.

Non-blocking version of wait_any. If no process has finished, this will just return None.

Will never return WaitAnyResult::ReceivedTerminationSignal.

Kills all subprocesses.

Send a SIGINT to all subprocesses and return immediately.

Send a SIGINT to all subprocesses and wait for them to finish.