pub struct SignalHandler { /* private fields */ }

Implementations

Override the default termination signals list.

Returns true if there are unprocessed termination signals.

This is useful for checking for termination signals in between different stages of processing, so that the application responds fast to signals.