Struct spawn_wait::SignalHandler
source · [−]pub struct SignalHandler { /* private fields */ }Implementations
sourceimpl SignalHandler
impl SignalHandler
sourcepub fn with_termination_signals(termination_signals: &[i32]) -> Self
pub fn with_termination_signals(termination_signals: &[i32]) -> Self
Override the default termination signals list.
pub fn add_termination_signal(&mut self, signal: i32)
sourcepub fn termination_pending(&mut self) -> bool
pub fn termination_pending(&mut self) -> bool
Returns true if there are unprocessed termination signals.
This is useful for checking for termination signals in between different stages of processing, so that the application responds fast to signals.